==> aliyun-java-sdk-edas-2.16.0-sources.jar: com/aliyuncs/edas/model/v20170801/ListConfigCentersRequest.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.aliyuncs.edas.model.v20170801;

import com.aliyuncs.RoaAcsRequest;
import com.aliyuncs.http.MethodType;

/**
 * @author auto create
 * @version 
 */
public class ListConfigCentersRequest extends RoaAcsRequest<ListConfigCentersResponse> {
	
	public ListConfigCentersRequest() {
		super("Edas", "2017-08-01", "ListConfigCenters");
		setUriPattern("/pop/v5/configCenters");
		setMethod(MethodType.GET);
	}

	private String logicalRegionId;

	private String dataIdPattern;

	private String group;

	public String getLogicalRegionId() {
		return this.logicalRegionId;
	}

	public void setLogicalRegionId(String logicalRegionId) {
		this.logicalRegionId = logicalRegionId;
		if(logicalRegionId != null){
			putQueryParameter("LogicalRegionId", logicalRegionId);
		}
	}

	public String getDataIdPattern() {
		return this.dataIdPattern;
	}

	public void setDataIdPattern(String dataIdPattern) {
		this.dataIdPattern = dataIdPattern;
		if(dataIdPattern != null){
			putQueryParameter("DataIdPattern", dataIdPattern);
		}
	}

	public String getGroup() {
		return this.group;
	}

	public void setGroup(String group) {
		this.group = group;
		if(group != null){
			putQueryParameter("Group", group);
		}
	}

	@Override
	public Class<ListConfigCentersResponse> getResponseClass() {
		return ListConfigCentersResponse.class;
	}

}

==> aliyun-java-sdk-edas-2.44.0-sources.jar: com/aliyuncs/edas/model/v20170801/ListConfigCentersRequest.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.aliyuncs.edas.model.v20170801;

import com.aliyuncs.RoaAcsRequest;
import com.aliyuncs.http.MethodType;

/**
 * @author auto create
 * @version 
 */
public class ListConfigCentersRequest extends RoaAcsRequest<ListConfigCentersResponse> {
	
	public ListConfigCentersRequest() {
		super("Edas", "2017-08-01", "ListConfigCenters");
		setUriPattern("/pop/v5/configCenters");
		setMethod(MethodType.GET);
	}

	private String appName;

	private String logicalRegionId;

	private String dataIdPattern;

	private String group;

	public String getAppName() {
		return this.appName;
	}

	public void setAppName(String appName) {
		this.appName = appName;
		if(appName != null){
			putQueryParameter("AppName", appName);
		}
	}

	public String getLogicalRegionId() {
		return this.logicalRegionId;
	}

	public void setLogicalRegionId(String logicalRegionId) {
		this.logicalRegionId = logicalRegionId;
		if(logicalRegionId != null){
			putQueryParameter("LogicalRegionId", logicalRegionId);
		}
	}

	public String getDataIdPattern() {
		return this.dataIdPattern;
	}

	public void setDataIdPattern(String dataIdPattern) {
		this.dataIdPattern = dataIdPattern;
		if(dataIdPattern != null){
			putQueryParameter("DataIdPattern", dataIdPattern);
		}
	}

	public String getGroup() {
		return this.group;
	}

	public void setGroup(String group) {
		this.group = group;
		if(group != null){
			putQueryParameter("Group", group);
		}
	}

	@Override
	public Class<ListConfigCentersResponse> getResponseClass() {
		return ListConfigCentersResponse.class;
	}

}
